@@ -16,7 +16,7 @@ execute_function <- function(object, requri, objectname="FUN"){
   #insert expressions
   exprargs <- sapply(fnargs, is.expression);
   if(length(exprargs) > 0){
-    argn[names(fnargs[exprargs])] <-lapply(fnargs[exprargs], "[[", 1);
+    argn[names(fnargs[exprargs])] <-lapply(fnargs[exprargs], function(z){if(length(z)) z[[1]] else substitute()});
   }  
 
   #construct call
